
import java.io.Serializable;

import java.util.Hashtable;

/**
 * A message is a lightweight object composed of a header and a
 * body.  The header contains identification and routing
 * information.  The body contains application data.
 *
 */

abstract
public
class Message
implements Serializable
{
  // Headers.

  private Destination _destinationDestination = null;
  private Destination _destinationReplyTo = null;

  protected
  void
  setDestination(Destination destinationDestination)
  {
    if (destinationDestination == null)
    {
      throw new NullPointerException("null Destination");
    }

    _destinationDestination = destinationDestination;
  }

  protected
  void
  setReplyTo(Destination destinationReplyTo)
  {
    if (destinationReplyTo == null)
    {
      throw new NullPointerException("null ReplyTo");
    }

    _destinationReplyTo = destinationReplyTo;
  }

  public
  Destination
  getDestination()
  {
    return _destinationDestination;
  }

  public
  Destination
  getReplyTo()
  {
    return _destinationReplyTo;
  }

  // Properties.

  private Hashtable _hashtableProperties = null;

  public
  void
  setObjectProperty(String stringName, Object objectValue)
  {
    if (stringName == null)
    {
      throw new NullPointerException("null name");
    }

    if (objectValue == null)
    {
      throw new NullPointerException("null value");
    }

    if (_hashtableProperties == null)
    {
      _hashtableProperties = new Hashtable();
    }

    _hashtableProperties.put(stringName, objectValue);
  }

  public
  Object
  getObjectProperty(String stringName)
  {
    return _hashtableProperties.get(stringName);
  }
}
